##  Overview
Once strategies are defined for each business capability, the next step is to conduct an [Application Portfolio Assessment](https://help.sap.com/docs/leanix/ea/application-portfolio-assessment?locale=en-US&state=PRODUCTION&version=CLOUD "Establish transparency and governance over your as-is landscape to identify optimization opportunities and unlock further use cases.") at the application level. Here, the pace layering classification becomes a valuable tool for prioritizing focus areas:
  * If the goal is to create new business value , prioritize business capabilities classified as "Innovation".
  * If the objective is [application rationalization](https://help.sap.com/docs/leanix/ea/application-rationalization?locale=en-US&state=PRODUCTION&version=CLOUD "Application rationalization reduces costs, eliminates redundancies, and improves efficiency. Optimize your application landscape with this step-by-step approach."), focus on "Commodity" capabilities. You can also narrow the scope by focusing on specific regions or business units.
  * If you're working on [application modernization](https://help.sap.com/docs/leanix/ea/application-modernization?locale=en-US&state=PRODUCTION&version=CLOUD "SAP LeanIX offers a strategic approach to modernizing outdated application portfolios, helping organizations reduce technical debt and operational costs while enhancing agility and innovation. This guide is useful for understanding how to effectively plan and execute continuous transformation tailored to specific organizational needs."), focus on applications supporting "Innovation" and "Differentiation" business capabilities and assess how many applications earmarked for cloud migration support such capabilities.
